@@ -9,10 +9,9 @@ from covsirphy.util.plotting import line_plot, box_plot
 from covsirphy.cleaning.term import Term
 from covsirphy.cleaning.jhu_data import JHUData
 from covsirphy.cleaning.population import PopulationData
-from covsirphy.ode.mbase import ModelBase
 from covsirphy.phase.phase_unit import PhaseUnit
 from covsirphy.phase.phase_series import PhaseSeries
-from covsirphy.phase.phase_estimator import MPEstimator
+from covsirphy.analysis.param_tracker import ParamTracker
 
 
 class Scenario(Term):
@@ -25,9 +24,10 @@ class Scenario(Term):
         country (str): country name
         province (str or None): province name
         tau (int or None): tau value
+        auto_complement (bool): if True, the number of cases will be complemented.
     """
 
-    def __init__(self, jhu_data, population_data, country, province=None, tau=None):
+    def __init__(self, jhu_data, population_data, country, province=None, tau=None, auto_complement=True):
         # Population
         population_data = self.ensure_instance(
             population_data, PopulationData, name="population_data")
@@ -39,14 +39,15 @@ class Scenario(Term):
         self.country = country
         self.province = province or self.UNKNOWN
         self.area = JHUData.area_name(country, province)
-        # First/last date of the area
-        df = jhu_data.subset(country=self.country, province=self.province)
-        self.subset_df = df.copy()
-        self._first_date = df[self.DATE].min().strftime(self.DATE_FORMAT)
-        self._last_date = df[self.DATE].max().strftime(self.DATE_FORMAT)
         # tau value must be shared
         self.tau = self.ensure_tau(tau)
-        # {scenario_name: PhaseSeries}
+        # Whether complement the number of cases or not
+        self._auto_complement = bool(auto_complement)
+        self._complemented = False
+        # Create {scenario_name: PhaseSeries} and set records
+        self.record_df = pd.DataFrame()
+        self._first_date = None
+        self._last_date = None
         self._init_phase_series()
 
     def __getitem__(self, key):
@@ -60,13 +61,62 @@ class Scenario(Term):
 
     def _init_phase_series(self):
         """
-        Initialize dictionary of phase series.
+        Initialize dictionary of phase series and set records.
+        Only when auto-complement mode, complement records if necessary.
         """
+        # Set records (complement records, if necessary)
+        if self._auto_complement:
+            self.complement()
+            if self.record_df.empty:
+                self.complement_reverse()
+        else:
+            self.complement_reverse()
+        if self.record_df.empty:
+            area = self.jhu_data.area_name(
+                self.country, province=self.province)
+            raise ValueError(
+                f"Records with 'Recovered > 0' in {area} are un-registered.")
+        # First/last date of the records
+        if self._first_date is None:
+            series = self.record_df.loc[:, self.DATE]
+            self._first_date = series.min().strftime(self.DATE_FORMAT)
+            self._last_date = series.max().strftime(self.DATE_FORMAT)
+        # Set main scenario
         self._series_dict = {
             self.MAIN: PhaseSeries(
                 self._first_date, self._last_date, self.population
             )
         }
+
+    def complement(self, interval=2, max_ignored=100):
+        """
+        Complement the number of recovered cases when not updated/reported.
+
+        Args:
+            interval (int): expected update interval of the number of recovered cases [days]
+            max_ignored (int): Max number of recovered cases to be ignored [cases]
+
+        Returns:
+            covsirphy.Scenario: self
+
+        Notes:
+            If the number of recovered cases did not change
+            for more than @interval days after reached @max_ignored cases,
+            complement will be applied to the number of recovered cases.
+        """
+        self.record_df, self._complemented = self.jhu_data.subset_complement(
+            country=self.country, province=self.province,
+            start_date=self._first_date, end_date=self._last_date, population=self.population,
+            interval=interval, max_ignored=max_ignored)
+        return self
+
+    def complement_reverse(self):
+        """
+        Restore the raw records. Reverse method of covsirphy.Scenario.complement().
+
+        Returns:
+            covsirphy.Scenario: self
+        """
         self.record_df = self.jhu_data.subset(
             country=self.country,
             province=self.province,
@@ -74,6 +124,8 @@ class Scenario(Term):
             end_date=self._last_date,
             population=self.population
         )
+        self._complemented = False
+        return self
 
     @property
     def first_date(self):
@@ -112,7 +164,7 @@ class Scenario(Term):
             filename (str): filename of the figure, or None (show figure)
 
         Returns:
-            (pandas.DataFrame)
+            pandas.DataFrame
                 Index:
                     reset index
                 Columns:
@@ -124,20 +176,35 @@ class Scenario(Term):
 
         Notes:
             Records with Recovered > 0 will be selected.
+            If complement was performed by Scenario.complement() or Scenario(auto_complement=True),
+            "(complemented)" will be added to the title of the figure.
         """
-        df = self.jhu_data.subset(
-            country=self.country, province=self.province,
-            start_date=self._first_date, end_date=self._last_date)
+        df = self.record_df.drop(self.S, axis=1)
         if not show_figure:
             return df
+        title = f"{self.area}: Cases over time{' (complemented)' if self._complemented else ''}"
         line_plot(
             df.set_index(self.DATE).drop(self.C, axis=1),
-            f"{self.area}: Cases over time",
+            title,
             y_integer=True,
             filename=filename
         )
         return df
 
+    def _create_tracker(self, name):
+        """
+        Create a instance of covsirphy.ParamTracker.
+
+        Args:
+            name (str): scenario name
+
+        Returns:
+            covsirphy.ParamTracker
+        """
+        return ParamTracker(
+            record_df=self.record_df, phase_series=self._ensure_name(name),
+            area=self.area, tau=self.tau)
+
     @deprecate(old="Scenario.add_phase()", new="Scenario.add()")
     def add_phase(self, **kwargs):
         return self.add(**kwargs)
@@ -280,10 +347,8 @@ class Scenario(Term):
         Returns:
             covsirphy.Scenario: self
         """
-        if not isinstance(phases, list):
-            raise TypeError("@phases must be a list of phase names.")
-        for phase in phases:
-            self._series_dict[name].disable(phase)
+        tracker = self._create_tracker(name)
+        self._series_dict[name] = tracker.disable(phases)
         return self
 
     def enable(self, phases, name="Main"):
@@ -297,10 +362,8 @@ class Scenario(Term):
         Returns:
             covsirphy.Scenario: self
         """
-        if not isinstance(phases, list):
-            raise TypeError("@phases must be a list of phase names.")
-        for phase in phases:
-            self._series_dict[name].enable(phase)
+        tracker = self._create_tracker(name)
+        self._series_dict[name] = tracker.enable(phases)
         return self
 
     def combine(self, phases, name="Main", population=None, **kwargs):
@@ -355,27 +418,14 @@ class Scenario(Term):
             date (str): change point, i.e. start date of the new phase
             name (str): scenario name
             population (int): population value of the change point
-            kwargs: keyword arguments of PhaseUnit.set_ode()
+            kwargs: keyword arguments of PhaseUnit.set_ode() if update is necessary
 
         Returns:
             covsirphy.Scenario: self
         """
-        series = self._ensure_name(name)
-        try:
-            phase, old = [
-                (self.num2str(i), unit) for (i, unit) in enumerate(series) if date in unit][0]
-        except IndexError:
-            raise IndexError(f"Phase on @date ({date}) is not registered.")
-        try:
-            new_pre = PhaseUnit(
-                old.start_date, self.yesterday(date), old.population)
-        except ValueError:
-            raise ValueError(
-                f"{name} scenario cannot be separated on {date} because this date is registered as a start date.") from None
-        new_pre.set_ode(**old.to_dict())
-        new_fol = PhaseUnit(date, old.end_date, population or old.population)
-        new_fol.set_ode(**kwargs)
-        self._series_dict[name].replaces(phase, [new_pre, new_fol])
+        tracker = self._create_tracker(name)
+        self._series_dict[name] = tracker.separate(
+            date, population=population, **kwargs)
         return self
 
     def _summary(self, name=None):
@@ -388,7 +438,7 @@ class Scenario(Term):
                 - if None, all phase series will be shown
 
         Returns:
-            (pandas.DataFrame):
+            pandas.DataFrame:
             - if @name not None, as the same as PhaseSeries().summary()
             - if @name is None, index will be phase series name and phase name
 
@@ -430,33 +480,34 @@ class Scenario(Term):
         """
         df = self._summary(name=name)
         all_cols = df.columns.tolist()
-        if set(self.EST_COLS).issubset(set(all_cols)):
+        if set(self.EST_COLS).issubset(all_cols):
             all_cols = [col for col in all_cols if col not in self.EST_COLS]
             all_cols += self.EST_COLS
         columns = columns or all_cols
         if not isinstance(columns, list):
             raise TypeError("@columns must be None or a list of strings.")
-        if not set(columns).issubset(set(df.columns)):
+        if not set(columns).issubset(df.columns):
             raise KeyError(
                 f"Un-registered columns were selected as @columns. Please use {', '.join(df.columns)}."
             )
         df = df.loc[:, columns]
         return df.dropna(how="all", axis=1).fillna(self.UNKNOWN)
 
-    def trend(self, set_phases=True, name="Main", show_figure=True, filename=None, **kwargs):
+    def trend(self, force=True, name="Main", show_figure=True, filename=None, **kwargs):
         """
         Perform S-R trend analysis and set phases.
 
         Args:
-            set_phases (bool): if True, set phases automatically with S-R trend analysis
+            force (bool): if True, change points will be over-written
             name (str): phase series name
             show_figure (bool): if True, show the result as a figure
-            filename (str): filename of the figure, or None (show figure)
+            filename (str): filename of the figure, or None (display)
             kwargs: keyword arguments of ChangeFinder()
 
         Returns:
             covsirphy.Scenario: self
         """
+        # Arguments
         if "n_points" in kwargs.keys():
             raise ValueError(
                 "@n_points argument is un-necessary"
@@ -466,55 +517,22 @@ class Scenario(Term):
             include_init_phase = kwargs.pop("include_init_phase")
         except KeyError:
             include_init_phase = True
-        self._ensure_name(name)
-        sr_df = self.jhu_data.to_sr(
-            country=self.country, province=self.province, population=self.population
-        )
-        self._series_dict[name].trend(
-            sr_df=sr_df,
-            set_phases=set_phases,
-            area=self.area,
-            show_figure=show_figure,
-            filename=filename,
-            **kwargs
-        )
+        try:
+            force = kwargs.pop("set_phases")
+        except KeyError:
+            pass
+        # S-R trend analysis
+        tracker = self._create_tracker(name)
+        self._series_dict[name] = tracker.trend(
+            force=force, show_figure=show_figure, filename=filename, **kwargs)
+        # Disable 0th phase, if necessary
         if not include_init_phase:
             self._series_dict[name].disable("0th")
         return self
 
-    def _ensure_past_phases(self, phases=None, name="Main"):
-        """
-        Ensure that the phases are past phases.
-
-        Args:
-            phases (list[str]): list of phase names, like 1st, 2nd...
-            name (str): phase series name
-
-        Returns:
-            list[covsirphy.PhaseUnit]: list of names of phase units
-
-        Notes:
-            If @phases is None, return the all past phases.
-        """
-        series = self._ensure_name(name)
-        past_units = [
-            unit.set_id(phase=self.num2str(num))
-            for (num, unit) in enumerate(series)
-            if unit and unit <= self.last_date and unit.id_dict is None
-        ]
-        if not past_units:
-            raise ValueError(
-                "Scenario.trend(), Scenario.enable() or Scenario.add() must be done in advance.")
-        if phases is None:
-            return past_units
-        if not isinstance(phases, list):
-            raise TypeError("@phases must be None or a list of phase names.")
-        selected_units = [series.unit(phase) for phase in phases]
-        return list(set(selected_units) & set(past_units))
-
     def estimate(self, model, phases=None, name="Main", n_jobs=-1, **kwargs):
         """
-        Estimate the parameters of the model using the records.
+        Perform parameter estimation for each phases.
 
         Args:
             model (covsirphy.ModelBase): ODE model
@@ -527,24 +545,15 @@ class Scenario(Term):
             - If 'Main' was used as @name, main PhaseSeries will be used.
             - If @name phase was not registered, new PhaseSeries will be created.
             - If @phases is None, all past phase will be used.
+            - Phases with estimated parameter values will be ignored.
             - In kwargs, tau value cannot be included.
         """
-        model = self.ensure_subclass(model, ModelBase, "model")
-        units = self._ensure_past_phases(phases=phases, name=name)
-        # tau value must be specified in Scenario.__init__
         if self.TAU in kwargs:
             raise ValueError(
                 "@tau must be specified when scenario = Scenario(), and cannot be specified here.")
-        # Parameter estimation
-        mp_estimator = MPEstimator(
-            record_df=self.record_df, model=model, tau=self.tau, **kwargs
-        )
-        mp_estimator.add(units)
-        results = mp_estimator.run(n_jobs=n_jobs, **kwargs)
-        self.tau = mp_estimator.tau
-        # Register the results
-        self._series_dict[name].replaces(
-            phase=None, new_list=results, keep_old=True)
+        tracker = self._create_tracker(name)
+        self.tau, self._series_dict[name] = tracker.estimate(
+            model=model, phases=phases, n_jobs=n_jobs, **kwargs)
 
     def phase_estimator(self, phase, name="Main"):
         """
@@ -596,19 +605,16 @@ class Scenario(Term):
 
     def simulate(self, name="Main", y0_dict=None, show_figure=True, filename=None):
         """
-        Simulate ODE models with set parameter values and show it as a figure.
+        Simulate ODE models with set/estimated parameter values and show it as a figure.
 
         Args:
             name (str): phase series name. If 'Main', main PhaseSeries will be used
-            y0_dict (dict or None): dictionary of initial values or None
-                - key (str): variable name
-                - value (float): initial value
-            show_figure (bool):
-                - if True, show the result as a figure.
+            y0_dict(dict[str, float] or None): dictionary of initial values of variables
+            show_figure (bool): if True, show the result as a figure
             filename (str): filename of the figure, or None (show figure)
 
         Returns:
-            (pandas.DataFrame)
+            pandas.DataFrame
                 Index:
                     reset index
                 Columns:
@@ -617,22 +623,27 @@ class Scenario(Term):
                     - Province (str): province/prefecture/state name
                     - Variables of the model and dataset (int): Confirmed etc.
         """
-        series = self._ensure_name(name)
-        # Simulation
-        sim_df = series.simulate(record_df=self.record_df, y0_dict=y0_dict)
+        tracker = self._create_tracker(name)
+        try:
+            sim_df = tracker.simulate(y0_dict=y0_dict)
+        except ValueError:
+            raise ValueError(
+                "Phases should be registered with Scenario.trend() or Scenario.add() in advance.") from None
+        except NameError:
+            raise NameError(
+                "Parameter estimation should be done with Scenario.estimate() in advance.") from None
         if not show_figure:
             return sim_df
         # Show figure
         df = sim_df.set_index(self.DATE)
         fig_cols_set = set(df.columns) & set(self.FIG_COLUMNS)
         fig_cols = [col for col in self.FIG_COLUMNS if col in fig_cols_set]
-        change_dates = [unit.start_date for unit in series][1:]
         line_plot(
             df[fig_cols],
-            title=f"{self.area}: Predicted number of cases ({name} scenario)",
+            title=f"{self.area}: Simulated number of cases ({name} scenario)",
             filename=filename,
             y_integer=True,
-            v=change_dates
+            v=tracker.change_dates()
         )
         return sim_df
 
@@ -647,7 +658,7 @@ class Scenario(Term):
             name (str): phase series name
 
         Returns:
-            (str or int or float)
+            str or int or float
 
         Notes:
             If 'Main' was used as @name, main PhaseSeries will be used.
@@ -668,7 +679,7 @@ class Scenario(Term):
             name (str): phase series name
 
         Returns:
-            (pandas.DataFrame): selected summary dataframe
+            pandas.DataFrame: selected summary dataframe
 
         Raises:
             KeyError: targets are not in the columns of summary dataframe
@@ -681,7 +692,7 @@ class Scenario(Term):
         selectable_cols = [self.N, *parameters, self.RT, *day_params]
         selectable_set = set(selectable_cols)
         df = series.summary().replace(self.UNKNOWN, None)
-        if not selectable_set.issubset(set(df.columns)):
+        if not selectable_set.issubset(df.columns):
             raise ValueError(
                 f"Scenario.estimate(model, phases=None, name={name}) must be done in advance.")
         targets = [targets] if isinstance(targets, str) else targets
@@ -752,7 +763,7 @@ class Scenario(Term):
                 - value (float): initial value
 
         Returns:
-            (pandas.DataFrame)
+            pandas.DataFrame
                 Index:
                     (int): scenario name
                 Columns:
@@ -800,9 +811,9 @@ class Scenario(Term):
             with_rt (bool): whether show the history of Rt values
 
         Returns:
-            (pandas.DataFrame)
+            pandas.DataFrame:
                 Index:
-                    (int): scenario name
+                    str: scenario name
                 Columns:
                     - max(Infected): max value of Infected
                     - argmax(Infected): the date when Infected shows max value
@@ -811,7 +822,7 @@ class Scenario(Term):
                     - Fatal({date}): Fatal on the next date of the last phase
                     - nth_Rt etc.: Rt value if the values are not the same values
         """
-        df = self._describe(y0_dict=None)
+        df = self._describe(y0_dict=y0_dict)
         if not with_rt or len(self._series_dict) == 1:
             return df
         # History of reproduction number
@@ -831,7 +842,7 @@ class Scenario(Term):
             name (str): phase series name
 
         Returns:
-            pandas.DataFrame
+            pandas.DataFrame:
                 Index: Date (pandas.TimeStamp)
                 Columns:
                     - Population (int)
@@ -870,7 +881,7 @@ class Scenario(Term):
                 - value (float): initial value
 
         Returns:
-            pandas.DataFrame
+            pandas.DataFrame:
                 Index: reset index
                 Columns:
                     - Date (pandas.TimeStamp)
@@ -887,17 +898,18 @@ class Scenario(Term):
             left_on=self.DATE, right_index=True, sort=True
         )
 
-    def track(self, y0_dict=None):
+    def track(self, with_actual=True, y0_dict=None):
         """
         Show values of parameters and variables in one dataframe.
 
         Args:
+            with_actual (bool): if True, show actual number of cases will included as "Actual" scenario
             y0_dict (dict or None): dictionary of initial values or None
                 - key (str): variable name
                 - value (float): initial value
 
         Returns:
-            pandas.DataFrame
+            pandas.DataFrame:
                 Index: reset index
                 Columns:
                     - Scenario (str)
@@ -914,39 +926,73 @@ class Scenario(Term):
             df = self._track(name=name, y0_dict=y0_dict)
             df.insert(0, self.SERIES, name)
             append(df)
+        if with_actual:
+            df = self.records(show_figure=False)
+            df.insert(0, self.SERIES, self.ACTUAL)
+            append(df)
         return pd.concat(dataframes, axis=0, sort=False)
 
-    def history(self, target, y0_dict=None, show_figure=True, filename=None):
+    def _history(self, target, with_actual=True, y0_dict=None):
         """
         Show the history of variables and parameter values to compare scenarios.
 
         Args:
-            target (str): parameter or variable to show (Rt etc.)
+            target (str): parameter or variable name to show (Rt, Infected etc.)
+            with_actual (bool): if True and @target is a variable name, show actual number of cases
+            y0_dict (dict or None): dictionary of initial values or None
+                - key (str): variable name
+                - value (float): initial value
+
+        Returns:
+            pandas.DataFrame
+        """
+        # Include actual data or not
+        with_actual = with_actual and target in self.VALUE_COLUMNS
+        # Get tracking data
+        df = self.track(with_actual=with_actual, y0_dict=y0_dict)
+        if target not in df.columns:
+            col_str = ", ".join(list(df.columns))
+            raise KeyError(
+                f"@target must be selected from {col_str}, but {target} was applied.")
+        # Select the records of target variable
+        return df.pivot_table(
+            values=target, index=self.DATE, columns=self.SERIES, aggfunc="last")
+
+    def history(self, target, with_actual=True, y0_dict=None, show_figure=True, filename=None):
+        """
+        Show the history of variables and parameter values to compare scenarios.
+
+        Args:
+            target (str): parameter or variable name to show (Rt, Infected etc.)
+            with_actual (bool): if True and @target is a variable name, show actual number of cases
             y0_dict (dict or None): dictionary of initial values or None
                 - key (str): variable name
                 - value (float): initial value
             show_figure (bool): If True, show the result as a figure
             filename (str): filename of the figure, or None (show figure)
+
+        Returns:
+            pandas.DataFrame
         """
-        df = self.track(y0_dict=y0_dict)
-        if target not in df.columns:
-            col_str = ", ".join(list(df.columns))
-            raise KeyError(
-                f"@target must be selected from {col_str}, but {target} was applied.")
-        df = df.pivot_table(
-            values=target, index=self.DATE, columns=self.SERIES, aggfunc="last"
+        df = self._history(
+            target=target, with_actual=with_actual, y0_dict=y0_dict)
+        if not show_figure:
+            return df
+        if target == self.RT:
+            ylabel = self.RT_FULL
+        elif target in self.VALUE_COLUMNS:
+            ylabel = f"The number of {target.lower()} cases"
+        else:
+            ylabel = target
+        title = f"{self.area}: {ylabel} over time"
+        tracker = self._create_tracker(self.MAIN)
+        line_plot(
+            df, title, ylabel=ylabel,
+            h=1.0 if target == self.RT else None,
+            v=tracker.change_dates(),
+            math_scale=False,
+            filename=filename
         )
-        if show_figure:
-            series = self._series_dict["Main"]
-            change_dates = [unit.start_date for unit in series][1:]
-            title = f"{self.area}: {self.RT_FULL if target == self.RT else target} over time"
-            line_plot(
-                df, title, ylabel=target,
-                h=1.0 if target == self.RT else None,
-                v=change_dates,
-                math_scale=False,
-                filename=filename
-            )
         return df
 
     def history_rate(self, params=None, name="Main", show_figure=True, filename=None):
@@ -959,6 +1005,9 @@ class Scenario(Term):
             name (str): phase series name
             show_figure (bool): If True, show the result as a figure
             filename (str): filename of the figure, or None (show figure)
+
+        Returns:
+            pandas.DataFrame
         """
         df = self._track_param(name=name)
         model = self._series_dict[name].unit("last").model
@@ -970,17 +1019,17 @@ class Scenario(Term):
             cols = list(set(cols) & set(params)) or cols
         df = df.loc[:, cols] / df.loc[df.index[0], cols]
         if show_figure:
-            series = self._series_dict[name]
-            change_dates = [unit.start_date for unit in series][1:]
             f_date = df.index[0].strftime(self.DATE_FORMAT)
             title = f"{self.area}: {model.NAME} parameter change rates over time (1.0 on {f_date})"
             ylabel = f"Value per that on {f_date}"
+            title = f"{self.area}: {ylabel} over time"
+            tracker = self._create_tracker(self.MAIN)
             line_plot(
-                df, title, ylabel=ylabel, v=change_dates, math_scale=False, filename=filename
-            )
+                df, title, ylabel=ylabel, v=tracker.change_dates(),
+                math_scale=False, filename=filename)
         return df
 
-    def retrospective(self, beginning_date, model, control="Main", target="Target", **args):
+    def retrospective(self, beginning_date, model, control="Main", target="Target", **kwargs):
         """
         Perform retrospective analysis.
         Compare the actual series of phases (control) and
@@ -991,20 +1040,24 @@ class Scenario(Term):
             model (covsirphy.ModelBase): ODE model
             control (str): scenario name of control
             target (str): scenario name of target
-            **args: keyword argument of parameters
+            kwargs: keyword argument of parameter values and Estimator.run()
 
         Notes:
             When parameter values are not specified,
             actual values of the last date before the beginning date will be used.
         """
+        param_dict = {
+            k: v for (k, v) in kwargs.items() if k in model.PARAMETERS}
+        est_kwargs = dict(kwargs.items() - param_dict.items())
         # Control
         self.clear(name=control, include_past=True)
         self.trend(name=control, show_figure=False)
-        series = self._series_dict[control]
-        sep_dates = [[ph.start_date, ph.end_date] for ph in series]
-        if beginning_date not in self.flatten(sep_dates):
-            self.separate(beginning_date, name=control)
-        self.estimate(model, name=control)
+        tracker = self._create_tracker(control)
+        try:
+            tracker.separate(beginning_date)
+        except ValueError:
+            pass
+        self.estimate(model, name=control, **est_kwargs)
         # Target
         self.clear(name=target, include_past=False, template=control)
         phases_changed = [
@@ -1012,5 +1065,53 @@ class Scenario(Term):
             if ph >= beginning_date
         ]
         self.delete(phases_changed, name=target)
-        self.add(name=target, **args)
-        self.estimate(model, name=target)
+        self.add(name=target, **param_dict)
+        self.estimate(model, name=target, **est_kwargs)
+
+    def score(self, metrics="RMSLE", variables=None, phases=None, past_days=None, name="Main", y0_dict=None):
+        """
+        Evaluate accuracy of phase setting and parameter estimation of all enabled phases all some past days.
+
+        Args:
+            metrics (str): "MAE", "MSE", "MSLE", "RMSE" or "RMSLE"
+            variables (list[str] or None): variables to use in calculation
+            phases (list[str] or None): phases to use in calculation
+            past_days (int or None): how many past days to use in calculation, natural integer
+            name(str): phase series name. If 'Main', main PhaseSeries will be used
+            y0_dict(dict[str, float] or None): dictionary of initial values of variables
+
+        Returns:
+            float: score with the specified metrics
+
+        Notes:
+            If @variables is None, ["Infected", "Fatal", "Recovered"] will be used.
+            "Confirmed", "Infected", "Fatal" and "Recovered" can be used in @variables.
+            If @phases is None, all phases will be used.
+            @phases and @past_days can not be specified at the same time.
+        """
+        name_temp = f"{name}_temporally_for_scoring"
+        self.clear(name=name_temp, include_past=False, template=name)
+        tracker = self._create_tracker(name_temp)
+        if past_days is not None:
+            if phases is not None:
+                raise ValueError(
+                    "@phases and @past_days cannot be specified at the same time.")
+            past_days = self.ensure_natural_int(past_days, name="past_days")
+            # Separate a phase, if possible
+            beginning_date = self.date_change(
+                self.last_date, days=0 - past_days)
+            try:
+                tracker.separate(date=beginning_date)
+            except ValueError:
+                pass
+            # Ge the list of target phases
+            phases = [
+                self.num2str(num) for (num, unit)
+                in enumerate(self._series_dict[name_temp])
+                if unit >= beginning_date
+            ]
+        score = tracker.score(
+            metrics=metrics, variables=variables, phases=phases, y0_dict=y0_dict)
+        if name_temp != name:
+            self.delete(name=name_temp)
+        return score
