@@ -12,12 +12,15 @@ class CountryData(CleaningBase):
     Data cleaning of country level data.
 
     Args:
-        filename (str): filename to read the data
+        filename (str or None): filename to read the data
         country (str): country name
     """
 
     def __init__(self, filename, country):
-        self._raw = dd.read_csv(filename).compute()
+        if filename is None:
+            self._raw = pd.DataFrame()
+        else:
+            self._raw = dd.read_csv(filename).compute()
         self._country = country
         self.province_col = None
         self.var_dict = {}
@@ -27,10 +30,7 @@ class CountryData(CleaningBase):
     @property
     def country(self):
         """
-        Return the country name.
-
-        Returns:
-            (str): country name
+        str: country name
         """
         return self._country
 
@@ -39,7 +39,7 @@ class CountryData(CleaningBase):
         Return the column names of the raw data.
 
         Returns:
-            (list[str]): the list of column names of the raw data
+            list[str]: the list of column names of the raw data
         """
         return self._raw.columns.tolist()
 
@@ -68,7 +68,7 @@ class CountryData(CleaningBase):
         This method overwrite super()._cleaning() method.
 
         Returns:
-            (pandas.DataFrame):
+            pandas.DataFrame:
                 Index:
                     reset index
                 Columns:
@@ -94,10 +94,7 @@ class CountryData(CleaningBase):
         # Remove empty rows
         df = df.dropna(subset=[self.DATE])
         # Add province column
-        if self.province_col:
-            df = df.rename({self.province_col: self.PROVINCE}, axis=1)
-        else:
-            df[self.PROVINCE] = self.UNKNOWN
+        df[self.PROVINCE] = self.UNKNOWN if self.province_col is None else df[self.province_col]
         # Values
         df[self.CI] = df[self.C] - df[self.F] - df[self.R]
         v_cols = self.VALUE_COLUMNS[:]
@@ -116,7 +113,7 @@ class CountryData(CleaningBase):
         Cleaning method is defined by CountryData._cleaning() method.
 
         Returns:
-            (pandas.DataFrame):
+            pandas.DataFrame:
                 Index:
                     reset index
                 Columns:
@@ -136,7 +133,7 @@ class CountryData(CleaningBase):
         Return a dataframe to show chronological change of number and rates.
 
         Returns:
-            (pandas.DataFrame): group-by Date, sum of the values
+            pandas.DataFrame: group-by Date, sum of the values
 
                 Index:
                     Date (pd.TimeStamp): Observation date
@@ -171,6 +168,6 @@ class CountryData(CleaningBase):
         Return names of countries where records are registered.
 
         Returns:
-            (list[str]): list of country names
+            list[str]: list of country names
         """
         return [self._country]
