@@ -13,7 +13,7 @@ class Term(object):
     """
     Term definition.
     """
-    # Variables of SIR-like model
+    # Variables of SIR-derived model
     N = "Population"
     S = "Susceptible"
     C = "Confirmed"
@@ -34,6 +34,9 @@ class Term(object):
     COUNTRY = "Country"
     ISO3 = "ISO3"
     PROVINCE = "Province"
+    STEP_N = "step_n"
+    Y0_DICT = "y0_dict"
+    PARAM_DICT = "param_dict"
     AREA_COLUMNS = [COUNTRY, PROVINCE]
     STR_COLUMNS = [DATE, *AREA_COLUMNS]
     COLUMNS = [*STR_COLUMNS, C, CI, F, R]
@@ -41,6 +44,7 @@ class Term(object):
     SUB_COLUMNS = [DATE, C, CI, F, R, S]
     VALUE_COLUMNS = [C, CI, F, R]
     FIG_COLUMNS = [CI, F, R, FR, V, E, W]
+    MONO_COLUMNS = [C, F, R]
     # Date format: 22Jan2020 etc.
     DATE_FORMAT = "%d%b%Y"
     # Separator of country and province
@@ -54,6 +58,7 @@ class Term(object):
     # Optimization
     A = "_actual"
     P = "_predicted"
+    ACTUAL = "Actual"
     # Phase name
     SUFFIX_DICT = defaultdict(lambda: "th")
     SUFFIX_DICT.update({1: "st", 2: "nd", 3: "rd"})
@@ -87,8 +92,7 @@ class Term(object):
         Returns:
             str
         """
-        if not isinstance(num, int):
-            raise TypeError("@num must be an integer.")
+        num = cls.ensure_natural_int(num, include_zero=True)
         q, mod = divmod(num, 10)
         suffix = "th" if q % 10 == 1 else cls.SUFFIX_DICT[mod]
         return f"{num}{suffix}"
@@ -126,6 +130,21 @@ class Term(object):
         """
         return a * np.exp(-b * x)
 
+    @staticmethod
+    def linear(x, a, b):
+        """
+        Linear function f(x)=A x + b.
+
+        Args:
+            x (float): x values
+            a (float): the first parameter of the function
+            b (float): the second parameter of the function
+
+        Returns:
+            float
+        """
+        return a * x + b
+
     @staticmethod
     def flatten(nested_list, unique=True):
         """
@@ -163,14 +182,14 @@ class Term(object):
             raise TypeError(f"Index of @{name} must be <pd.DatetimeIndex>.")
         if columns is None:
             return df
-        if not set(columns).issubset(set(df.columns)):
+        if not set(columns).issubset(df.columns):
             cols_str = ", ".join(
                 [col for col in columns if col not in df.columns]
             )
             included = ", ".join(df.columns.tolist())
             s1 = f"Expected columns were not included in {name} with {included}."
             raise KeyError(
-                f"{s1} However, {cols_str} must be included."
+                f"{s1} {cols_str} must be included."
             )
         return df
 
@@ -319,6 +338,36 @@ class Term(object):
             raise TypeError(s)
         return target
 
+    @staticmethod
+    def ensure_list(target, candidates=None, name="target"):
+        """
+        Ensure the target is a sub-list of the candidates.
+
+        Args:
+            target (list[object]): target to ensure
+            candidates (list[object] or None): list of candidates, if we have
+            name (str): argument name of the target
+
+        Returns:
+            object: as-is target
+        """
+        if not isinstance(target, (list, tuple)):
+            raise TypeError(
+                f"@{name} must be a list or tuple, but {type(target)} was applied.")
+        if candidates is None:
+            return target
+        # Check the target is a sub-list of candidates
+        try:
+            candidate_str = ", ".join(candidates)
+        except TypeError:
+            raise TypeError(
+                f"@candidates must be a list, but {candidates} was applied.") from None
+        ok_list = [element in candidates for element in target]
+        if all(ok_list):
+            return target
+        raise KeyError(
+            f"@{name} must be a sub-list of {candidate_str}, but {target} was applied.") from None
+
     @classmethod
     def divisors(cls, value):
         """
