@@ -6,15 +6,15 @@ import warnings
 import pandas as pd
 import pytest
 from covsirphy import Scenario
-from covsirphy import Term, PhaseSeries, SIR
+from covsirphy import Term, PhaseSeries, SIR, SIRF
 
 
 class TestScenario(object):
-    @pytest.mark.parametrize("country", ["Italy", "Japan"])
+    @pytest.mark.parametrize("country", ["Italy", "Japan", "Netherlands"])
     @pytest.mark.parametrize("province", [None, "Tokyo"])
     @pytest.mark.parametrize("tau", [None, 720, 1000])
     def test_start(self, jhu_data, population_data, country, province, tau):
-        if country == "Italy" and province == "Tokyo":
+        if province == "Tokyo" and country != "Japan":
             with pytest.raises(KeyError):
                 Scenario(
                     jhu_data, population_data, country, province=province)
@@ -35,7 +35,7 @@ class TestScenario(object):
         population = population_data.value(country)
         sr_df = jhu_data.to_sr(country=country, population=population)
         series = PhaseSeries("01Apr2020", "01Aug2020", population)
-        series.trend(sr_df, show_figure=False)
+        series.trend(sr_df)
         # Add scenario
         snl["New"] = series
         # Get scenario
@@ -150,8 +150,6 @@ class TestScenario(object):
         snl.combine(["2nd", "3rd"], population=n_changed)
         assert len(snl["Main"]) == length - 2
         # Separate
-        with pytest.raises(IndexError):
-            snl.separate(date="01Dec2020")
         snl.separate(date="01May2020")
         assert len(snl["Main"]) == length - 1
 
@@ -168,10 +166,10 @@ class TestScenario(object):
         # Show two scenarios
         snl.clear(name="New")
         cols = snl.summary().reset_index().columns
-        assert set([Term.SERIES, Term.PHASE]).issubset(set(cols))
+        assert set([Term.SERIES, Term.PHASE]).issubset(cols)
         # Show selected scenario
         cols_sel = snl.summary(name="New").reset_index().columns
-        assert not set([Term.SERIES, Term.PHASE]).issubset(set(cols_sel))
+        assert not set([Term.SERIES, Term.PHASE]).issubset(cols_sel)
         # Columns to show
         show_cols = [Term.N, Term.START]
         assert set(snl.summary(columns=show_cols).columns) == set(show_cols)
@@ -182,7 +180,7 @@ class TestScenario(object):
         # To markdown
         snl.summary().to_markdown()
 
-    @pytest.mark.parametrize("country", ["Greece"])
+    @pytest.mark.parametrize("country", ["Japan"])
     def test_estimate(self, jhu_data, population_data, country):
         warnings.simplefilter("ignore", category=UserWarning)
         # Setting
@@ -191,27 +189,19 @@ class TestScenario(object):
         snl.last_date = "01Aug2020"
         with pytest.raises(ValueError):
             snl.estimate(SIR)
-        snl.trend(include_init_phase=True, show_figure=False)
-        snl.disable(phases=["0th"])
+        snl.trend(show_figure=False)
         with pytest.raises(AttributeError):
-            snl.estimate_history(phase="1th")
+            snl.estimate_history(phase="last")
         # Parameter estimation
         with pytest.raises(KeyError):
             snl.estimate(SIR, phases=["30th"])
         with pytest.raises(ValueError):
             snl.estimate(model=SIR, tau=1440)
-        snl.enable(phases=["0th"])
-        with pytest.raises(TypeError):
-            snl.estimate(model=SIR, phases="1st")
-        with pytest.raises(ValueError):
-            snl.estimate(model=SIR, phases=["0th"])
-        snl.clear(include_past=True)
-        snl.trend(show_figure=False)
-        snl.estimate(SIR)
+        snl.estimate(SIR, timeout=5, timeout_iteration=5)
         # Estimation history
-        snl.estimate_history(phase="1st")
+        snl.estimate_history(phase="last")
         # Estimation accuracy
-        snl.estimate_accuracy(phase="1st")
+        snl.estimate_accuracy(phase="last")
         # Get a value
         snl.get(Term.RT)
         with pytest.raises(KeyError):
@@ -223,7 +213,7 @@ class TestScenario(object):
         snl = Scenario(jhu_data, population_data, country)
         snl.trend(show_figure=False)
         with pytest.raises(ValueError):
-            snl.estimate(SIR, tau=1440)
+            snl.estimate(SIR, tau=1440, timeout=20)
 
     @pytest.mark.parametrize("country", ["Japan"])
     def test_simulate(self, jhu_data, population_data, country):
@@ -232,13 +222,19 @@ class TestScenario(object):
         # Setting
         snl = Scenario(jhu_data, population_data, country)
         snl.first_date = "01Apr2020"
-        snl.last_date = "01Aug2020"
+        snl.last_date = "01May2020"
+        with pytest.raises(ValueError):
+            snl.simulate()
         snl.trend(show_figure=False)
         # Parameter estimation
         with pytest.raises(ValueError):
             # Deprecated
             snl.param_history(["rho"])
-        snl.estimate(SIR)
+        all_phases = snl.summary().index.tolist()
+        snl.disable(all_phases[:-2])
+        with pytest.raises(NameError):
+            snl.simulate()
+        snl.estimate(SIR, timeout=5, timeout_iteration=5)
         # Simulation
         snl.simulate()
         # Parameter history (Deprecated)
@@ -268,8 +264,43 @@ class TestScenario(object):
         # Setting
         snl = Scenario(jhu_data, population_data, country)
         snl.first_date = "01Apr2020"
-        snl.last_date = "19Oct2020"
+        snl.last_date = "01Jun2020"
         snl.trend(show_figure=False)
         # Retrospective analysis
         snl.retrospective(
-            "01Sep2020", model=SIR, control="Main", target="Retrospective")
+            "01May2020", model=SIR, control="Main", target="Retrospective",
+            timeout=5, timeout_iteration=5)
+
+    @pytest.mark.parametrize("country", ["Greece"])
+    def test_complement(self, jhu_data, population_data, country):
+        max_ignored = 100
+        # Auto complement
+        snl = Scenario(
+            jhu_data, population_data, country, auto_complement=True)
+        recovered = snl.records(show_figure=False)[Term.R]
+        assert recovered[recovered > max_ignored].value_counts().max() == 1
+        # Restore the raw data
+        snl.complement_reverse()
+        recovered = snl.records(show_figure=False)[Term.R]
+        assert recovered[recovered > max_ignored].value_counts().max() != 1
+        # Complement
+        snl.complement()
+        recovered = snl.records(show_figure=False)[Term.R]
+        assert recovered[recovered > max_ignored].value_counts().max() == 1
+
+    @pytest.mark.parametrize("country", ["Italy"])
+    def test_score(self, jhu_data, population_data, country):
+        snl = Scenario(jhu_data, population_data, country, tau=360)
+        snl.trend(show_figure=False)
+        snl.estimate(SIRF, timeout=5, timeout_iteration=5)
+        assert isinstance(snl.score(metrics="RMSLE"), float)
+        # Selected phases
+        df = snl.summary()
+        all_phases = df.index.tolist()
+        sel_score = snl.score(phases=all_phases[-2:])
+        # Selected past days (when the begging date is a start date)
+        beginning_date = df.loc[df.index[-2], Term.START]
+        past_days = Term.steps(beginning_date, snl.last_date, tau=1440)
+        assert snl.score(past_days=past_days) == sel_score
+        # Selected past days
+        snl.score(past_days=60)
